@@ -7,7 +7,7 @@ from django.forms import ValidationError
 # importa las entidades utilizadas aqui
 from ..models import [[ entity_name.capitalize() ]]
 from .mappers import Mapper
-from ..utils.clean_dict_of_keys import clean_dict_of_keys
+from ..utils.filter_dict import clean_dict_of_keys
 from ..utils.is_integer import is_integer
 from ..utils.is_uuid import is_uuid
 from ..domain.entities import [[ entity_name.capitalize() ]]Entity
@@ -39,6 +39,14 @@ class [[ entity_name.capitalize() ]]Repository:
     - Métodos básicos.
     """
 
+    # Campos de la entidad no persistibles en el repositorio (para lógica de actualización)
+    # Los campos no persistibles son aquellos que nunca cambian como: id, uuid, created_at, updated_at, etc.
+    # aquellos que tienen una forma especial de ser guardados como: photo, password, etc.
+    # y también los campos ManyToManyField
+    ENTITY_NOT_PERSISTIBLE_FIELDS = {
+        'id', 'uuid', 'externals'
+    }    
+
     @staticmethod
     def get_all(filters: Optional[dict] = None) -> List[ [[ entity_name.capitalize() ]]Entity ]:
         """
@@ -211,8 +219,8 @@ class [[ entity_name.capitalize() ]]Repository:
             #convertir a dict
             data = entity.to_dict()        
 
-            # Eliminar de la data las propiedades que requieren un tratamiento especial
-            data = clean_dict_of_keys(data, keys=entity.SPECIAL_FIELDS)
+            # Filtrar solo los campos actualizables
+            data = clean_dict_of_keys(data, keys=[[ entity_name.capitalize() ]]Repository.ENTITY_NOT_PERSISTIBLE_FIELDS)              
 
             # Crear el registro a partir de los campos presentes en la 'data'
             instance = [[ entity_name.capitalize() ]](**data)
@@ -302,13 +310,12 @@ class [[ entity_name.capitalize() ]]Repository:
 
             with transaction.atomic():
                 # Asegurar que todas las operaciones se realicen en una transacción
-                # Esto garantiza que si algo falla, no se guarden cambios parciales            
-
+                # Esto garantiza que si algo falla, no se guarden cambios parciales     
+                
                 # Actualizar cada campo de la entidad en el modelo
                 for key, value in entity.to_dict().items():
-                    if hasattr(instance, key):
-                        if not key in entity.SPECIAL_FIELDS: # No actualizar campos especiales
-                            setattr(instance, key, value)
+                    if (key is not None) and (not key in [[ entity_name.capitalize() ]]Repository.ENTITY_NOT_PERSISTIBLE_FIELDS) and hasattr(instance, key):
+                        setattr(instance, key, value)                
 
                 # Si se proporciona un ID de otra entidad, actualizarlo
                 if external_id is not None:
